/*
 * RomRaider Open-Source Tuning, Logging and Reflashing
 * Copyright (C) 2006-2012 RomRaider.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

package com.romraider.logger.external.te.io;

import com.romraider.io.serial.connection.SerialConnection;
import static com.romraider.util.ThreadUtil.sleep;

public final class TestTEConnection implements SerialConnection {
/*
    2.0 Data Frame Format:
    Byte - Description
    1 - Frame Header byte 1 (0x5A)
    2 - Frame Header byte 2 (0xA5)
    3 - Frame Sequence counter
    4 - Tick [high] (1 tick = 1/100 Second)
    5 - Tick [low] byte
    6 - l-16 or Ipx(0), (or ADC) [high] byte
    7 - l-16 or Ipx(0), (or ADC) [low] byte
    8 - Ipx(1) [high] (8192=F/A, 4096=Ipx[0])
    9 - Ipx(1) [low] byte
    10 - User 1 ADC [high] (V1 input)
    11 - User 1 ADC [low] byte
    12 - User 2 ADC [high] (V2 input)
    13 - User 2 ADC [low] byte
    14 - User 3 ADC [high] (V3 input)
    15 - User 3 ADC [low] byte
    16 - Thermocouple 1 ADC [high] (T1 Input)
    17 - Thermocouple 1 ADC [low]
    18 - Thermocouple 2 ADC [high] (T2 Input)
    19 - Thermocouple 2 ADC [low]
    20 - Thermocouple 3 ADC [high] (T3 Input)
    21 - Thermocouple 3 ADC [low]
    22 - Thermistor ADC or Vss count [high]
    23 - Thermistor ADC or Vss count [low]
    24 - RPM count [high] byte
    25 - RPM count [low] bye
    26 - Status/Error [high] byte
    27 - Status/Error [low] byte
    28 - CRC (1's comp. sum of above)
 */
//    private byte[] data = { // frame 2.0
//            (byte) 0x5a,
//            (byte) 0xa5,
//            (byte) 0x02,    // frame count
//            (byte) 0x89,
//            (byte) 0x00,
//            (byte) 0x1f,    // lambda [high]
//            (byte) 0xf4,    // lambda [low]
//            (byte) 0x01,    // Ipx(1) [high]
//            (byte) 0x00,    // Ipx(1) [low]
//            (byte) 0x1f,    // user1 [high]
//            (byte) 0xf8,    // user1 [low]
//            (byte) 0x0f,
//            (byte) 0xfc,
//            (byte) 0x00,
//            (byte) 0x21,
//            (byte) 0x03,    // tc1 [high]
//            (byte) 0xf8,    // tc1 [low]
//            (byte) 0x01,
//            (byte) 0xfc,
//            (byte) 0x00,
//            (byte) 0x20,
//            (byte) 0x09,
//            (byte) 0x00,
//            (byte) 0x03,    // RPM count [high]
//            (byte) 0xec,    // RPM count [low]
//            (byte) 0x0b,
//            (byte) 0x00,
//            (byte) 0x00
//            };
//    private byte[] data = { // frame 1.5
//            (byte) 0x5a,
//            (byte) 0xa5,
//            (byte) 0x09,    // frame count
//            (byte) 0x7f,    // lambda [high]
//            (byte) 0x00,    // lambda [low]
//            (byte) 0x1f,    // user1 [high]
//            (byte) 0xf4,    // user1 [low]
//            (byte) 0x01,
//            (byte) 0x00,
//            (byte) 0x1f,    // RPM count [high]
//            (byte) 0xf8,    // RPM count [low]
//            (byte) 0x0f,
//            };

    private byte[] data = {
//                    0          1          2         3          4          5          6          7          8          9         10        11        12        13        14        15        16        17        18        19        20        21        22        23        24        25        26         27
            (byte)0x5A,(byte)0xA5,(byte)0x2,(byte)0x42,(byte)0xDE,(byte)0x12,(byte)0xF8,(byte)0x11,(byte)0x36,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6F, 
            (byte)0x5A,(byte)0xA5,(byte)0x3,(byte)0x42,(byte)0xE9,(byte)0x13,(byte)0xB,(byte)0x11,(byte)0x3D,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4A, 
            (byte)0x5A,(byte)0xA5,(byte)0x4,(byte)0x42,(byte)0xF4,(byte)0x12,(byte)0xF0,(byte)0x11,(byte)0x33,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x63, 
            (byte)0x5A,(byte)0xA5,(byte)0x5,(byte)0x42,(byte)0xFF,(byte)0x12,(byte)0xE3,(byte)0x11,(byte)0x2F,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5F, 
            (byte)0x5A,(byte)0xA5,(byte)0x6,(byte)0x43,(byte)0xA,(byte)0x12,(byte)0xEB,(byte)0x11,(byte)0x31,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4E, 
            (byte)0x5A,(byte)0xA5,(byte)0x7,(byte)0x43,(byte)0x15,(byte)0x12,(byte)0xF6,(byte)0x11,(byte)0x35,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x34, 
            (byte)0x5A,(byte)0xA5,(byte)0x8,(byte)0x43,(byte)0x20,(byte)0x12,(byte)0xEB,(byte)0x11,(byte)0x31,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3A, 
            (byte)0x5A,(byte)0xA5,(byte)0x9,(byte)0x43,(byte)0x2B,(byte)0x12,(byte)0xEE,(byte)0x11,(byte)0x32,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x22, 
            (byte)0x5A,(byte)0xA5,(byte)0xA,(byte)0x43,(byte)0x36,(byte)0x12,(byte)0xEE,(byte)0x11,(byte)0x32,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x27, // checksum bad, should be 0x17
            (byte)0x5A,(byte)0xA5,(byte)0xB,(byte)0x43,(byte)0x41,(byte)0x12,(byte)0xE6,(byte)0x11,(byte)0x2F,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1D, 
            (byte)0x5A,(byte)0xA5,(byte)0xC,(byte)0x43,(byte)0x4C,(byte)0x12,(byte)0xEB,(byte)0x11,(byte)0x31,(byte)0x0,(byte)0x12,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x11, 
            (byte)0x5A,(byte)0xA5,(byte)0xD,(byte)0x43,(byte)0x57,(byte)0x13,(byte)0x19,(byte)0x11,(byte)0x42,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBB, 
            (byte)0x5A,(byte)0xA5,(byte)0xE,(byte)0x43,(byte)0x62,(byte)0x13,(byte)0x52,(byte)0x11,(byte)0x57,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x62, 
            (byte)0x5A,(byte)0xA5,(byte)0xF,(byte)0x43,(byte)0x6D,(byte)0x13,(byte)0xB8,(byte)0x11,(byte)0x7D,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC5, 
            (byte)0x5A,(byte)0xA5,(byte)0x10,(byte)0x43,(byte)0x78,(byte)0x14,(byte)0x32,(byte)0x11,(byte)0xA8,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1A, 
            (byte)0x5A,(byte)0xA5,(byte)0x11,(byte)0x43,(byte)0x83,(byte)0x14,(byte)0x4E,(byte)0x11,(byte)0xB2,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE8, 
            (byte)0x5A,(byte)0xA5,(byte)0x12,(byte)0x43,(byte)0x8E,(byte)0x14,(byte)0x27,(byte)0x11,(byte)0xA4,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA, 
            (byte)0x5A,(byte)0xA5,(byte)0x13,(byte)0x43,(byte)0x99,(byte)0x15,(byte)0x89,(byte)0x12,(byte)0x17,(byte)0x0,(byte)0x24,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x23, 
            (byte)0x5A,(byte)0xA5,(byte)0x14,(byte)0x43,(byte)0xA4,(byte)0x16,(byte)0x51,(byte)0x12,(byte)0x61,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8, 
            (byte)0x5A,(byte)0xA5,(byte)0x15,(byte)0x43,(byte)0xAF,(byte)0x15,(byte)0x86,(byte)0x12,(byte)0x1E,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8, 
            (byte)0x5A,(byte)0xA5,(byte)0x16,(byte)0x43,(byte)0xBA,(byte)0x14,(byte)0x54,(byte)0x11,(byte)0xB4,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA1, 
            (byte)0x5A,(byte)0xA5,(byte)0x17,(byte)0x43,(byte)0xC5,(byte)0x13,(byte)0x95,(byte)0x11,(byte)0x70,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x92, 
            (byte)0x5A,(byte)0xA5,(byte)0x18,(byte)0x43,(byte)0xD0,(byte)0x13,(byte)0x11,(byte)0x11,(byte)0x3F,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3E, 
            (byte)0x5A,(byte)0xA5,(byte)0x19,(byte)0x43,(byte)0xDB,(byte)0x12,(byte)0x55,(byte)0x10,(byte)0xF8,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3B, 
            (byte)0x5A,(byte)0xA5,(byte)0x1A,(byte)0x43,(byte)0xE6,(byte)0x11,(byte)0x6B,(byte)0x10,(byte)0x8E,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x7D, 
            (byte)0x5A,(byte)0xA5,(byte)0x1B,(byte)0x43,(byte)0xF1,(byte)0x11,(byte)0x3,(byte)0x10,(byte)0x58,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1A, 
            (byte)0x5A,(byte)0xA5,(byte)0x1C,(byte)0x43,(byte)0xFC,(byte)0x10,(byte)0x2A,(byte)0xF,(byte)0xDF,(byte)0x0,(byte)0x12,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x68, 
            (byte)0x5A,(byte)0xA5,(byte)0x1D,(byte)0x44,(byte)0x7,(byte)0xF,(byte)0x92,(byte)0xF,(byte)0x82,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4B, 
            (byte)0x5A,(byte)0xA5,(byte)0x1E,(byte)0x44,(byte)0x12,(byte)0xF,(byte)0x50,(byte)0xF,(byte)0x4D,(byte)0x0,(byte)0x15,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB9, 
            (byte)0x5A,(byte)0xA5,(byte)0x1F,(byte)0x44,(byte)0x1D,(byte)0xF,(byte)0x34,(byte)0xF,(byte)0x36,(byte)0x0,(byte)0x17,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xDE, 
            (byte)0x5A,(byte)0xA5,(byte)0x20,(byte)0x44,(byte)0x28,(byte)0xF,(byte)0x2D,(byte)0xF,(byte)0x30,(byte)0x0,(byte)0x10,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE6, 
            (byte)0x5A,(byte)0xA5,(byte)0x21,(byte)0x44,(byte)0x33,(byte)0xF,(byte)0x5D,(byte)0xF,(byte)0x57,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x7B, 
            (byte)0x5A,(byte)0xA5,(byte)0x22,(byte)0x44,(byte)0x3E,(byte)0xF,(byte)0xC5,(byte)0xF,(byte)0xA1,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBB, 
            (byte)0x5A,(byte)0xA5,(byte)0x23,(byte)0x44,(byte)0x49,(byte)0x10,(byte)0x1D,(byte)0xF,(byte)0xD7,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1C, 
            (byte)0x5A,(byte)0xA5,(byte)0x24,(byte)0x44,(byte)0x54,(byte)0x10,(byte)0xE9,(byte)0x10,(byte)0x4A,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCB, 
            (byte)0x5A,(byte)0xA5,(byte)0x25,(byte)0x44,(byte)0x5F,(byte)0x11,(byte)0xDA,(byte)0x10,(byte)0xC0,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x60, 
            (byte)0x5A,(byte)0xA5,(byte)0x26,(byte)0x44,(byte)0x6A,(byte)0x12,(byte)0xE0,(byte)0x11,(byte)0x2D,(byte)0x0,(byte)0x24,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD5, 
            (byte)0x5A,(byte)0xA5,(byte)0x27,(byte)0x44,(byte)0x75,(byte)0x14,(byte)0x65,(byte)0x11,(byte)0xBA,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBC, 
            (byte)0x5A,(byte)0xA5,(byte)0x28,(byte)0x44,(byte)0x80,(byte)0x16,(byte)0xC8,(byte)0x12,(byte)0x88,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x77, 
            (byte)0x5A,(byte)0xA5,(byte)0x29,(byte)0x44,(byte)0x8B,(byte)0x15,(byte)0x6E,(byte)0x12,(byte)0x16,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x41, 
            (byte)0x5A,(byte)0xA5,(byte)0x2A,(byte)0x44,(byte)0x96,(byte)0x12,(byte)0xDB,(byte)0x11,(byte)0x2B,(byte)0x0,(byte)0x13,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBD, 
            (byte)0x5A,(byte)0xA5,(byte)0x2B,(byte)0x44,(byte)0xA1,(byte)0x10,(byte)0xAE,(byte)0x10,(byte)0x2A,(byte)0x0,(byte)0x11,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE4, 
            (byte)0x5A,(byte)0xA5,(byte)0x2C,(byte)0x44,(byte)0xAC,(byte)0xF,(byte)0xA9,(byte)0xF,(byte)0x93,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x71, 
            (byte)0x5A,(byte)0xA5,(byte)0x2D,(byte)0x44,(byte)0xB7,(byte)0xF,(byte)0x8B,(byte)0xF,(byte)0x7D,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x99, 
            (byte)0x5A,(byte)0xA5,(byte)0x2E,(byte)0x44,(byte)0xC2,(byte)0xF,(byte)0xAC,(byte)0xF,(byte)0x92,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x57, 
            (byte)0x5A,(byte)0xA5,(byte)0x2F,(byte)0x44,(byte)0xCD,(byte)0xF,(byte)0x65,(byte)0xF,(byte)0x5E,(byte)0x0,(byte)0xF,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCD, 
            (byte)0x5A,(byte)0xA5,(byte)0x30,(byte)0x44,(byte)0xD8,(byte)0xF,(byte)0x1B,(byte)0xF,(byte)0x21,(byte)0x0,(byte)0xE,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x49, 
            (byte)0x5A,(byte)0xA5,(byte)0x31,(byte)0x44,(byte)0xE3,(byte)0xE,(byte)0xA3,(byte)0xE,(byte)0xC0,(byte)0x0,(byte)0x12,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x14, 
            (byte)0x5A,(byte)0xA5,(byte)0x32,(byte)0x44,(byte)0xEE,(byte)0xD,(byte)0xFE,(byte)0xE,(byte)0x2C,(byte)0x0,(byte)0x10,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x44, 
            (byte)0x5A,(byte)0xA5,(byte)0x33,(byte)0x44,(byte)0xF9,(byte)0xD,(byte)0xBF,(byte)0xD,(byte)0xED,(byte)0x0,(byte)0x12,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB5, 
            (byte)0x5A,(byte)0xA5,(byte)0x34,(byte)0x45,(byte)0x4,(byte)0xE,(byte)0x15,(byte)0xE,(byte)0x42,(byte)0x0,(byte)0x11,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFC, 
            (byte)0x5A,(byte)0xA5,(byte)0x35,(byte)0x45,(byte)0xF,(byte)0xE,(byte)0xCC,(byte)0xE,(byte)0xE1,(byte)0x0,(byte)0x11,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9A, 
            (byte)0x5A,(byte)0xA5,(byte)0x36,(byte)0x45,(byte)0x1A,(byte)0xF,(byte)0xE7,(byte)0xF,(byte)0xB6,(byte)0x0,(byte)0x14,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x99, 
            (byte)0x5A,(byte)0xA5,(byte)0x37,(byte)0x45,(byte)0x25,(byte)0x10,(byte)0x0,(byte)0xF,(byte)0xC5,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x60, 
            (byte)0x5A,(byte)0xA5,(byte)0x38,(byte)0x45,(byte)0x30,(byte)0x11,(byte)0x40,(byte)0x10,(byte)0x79,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5A, 
            (byte)0x5A,(byte)0xA5,(byte)0x39,(byte)0x45,(byte)0x3B,(byte)0x12,(byte)0x6F,(byte)0x11,(byte)0x3,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x96, 
            (byte)0x5A,(byte)0xA5,(byte)0x3A,(byte)0x45,(byte)0x46,(byte)0x13,(byte)0xD2,(byte)0x11,(byte)0x8A,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9B, 
            (byte)0x5A,(byte)0xA5,(byte)0x3B,(byte)0x45,(byte)0x51,(byte)0x14,(byte)0x57,(byte)0x11,(byte)0xB5,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xDB, 
            (byte)0x5A,(byte)0xA5,(byte)0x3C,(byte)0x45,(byte)0x5C,(byte)0x15,(byte)0x89,(byte)0x12,(byte)0x1F,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x33, 
            (byte)0x5A,(byte)0xA5,(byte)0x3D,(byte)0x45,(byte)0x67,(byte)0x15,(byte)0xA4,(byte)0x12,(byte)0x28,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6, 
            (byte)0x5A,(byte)0xA5,(byte)0x3E,(byte)0x45,(byte)0x72,(byte)0x15,(byte)0x1,(byte)0x11,(byte)0xF1,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD0, 
            (byte)0x5A,(byte)0xA5,(byte)0x3F,(byte)0x45,(byte)0x7D,(byte)0x14,(byte)0x40,(byte)0x11,(byte)0xAD,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD1, 
            (byte)0x5A,(byte)0xA5,(byte)0x40,(byte)0x45,(byte)0x88,(byte)0x13,(byte)0x90,(byte)0x11,(byte)0x6E,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB2, 
            (byte)0x5A,(byte)0xA5,(byte)0x41,(byte)0x45,(byte)0x93,(byte)0x12,(byte)0xFE,(byte)0x11,(byte)0x38,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x70, 
            (byte)0x5A,(byte)0xA5,(byte)0x42,(byte)0x45,(byte)0x9E,(byte)0x12,(byte)0xBD,(byte)0x11,(byte)0x20,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBB, 
            (byte)0x5A,(byte)0xA5,(byte)0x43,(byte)0x45,(byte)0xA9,(byte)0x12,(byte)0xAF,(byte)0x11,(byte)0x1B,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC1, 
            (byte)0x5A,(byte)0xA5,(byte)0x44,(byte)0x45,(byte)0xB4,(byte)0x12,(byte)0xF8,(byte)0x11,(byte)0x36,(byte)0x0,(byte)0x25,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4A, 
            (byte)0x5A,(byte)0xA5,(byte)0x45,(byte)0x45,(byte)0xBF,(byte)0x13,(byte)0x5C,(byte)0x11,(byte)0x5B,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB9, 
            (byte)0x5A,(byte)0xA5,(byte)0x46,(byte)0x45,(byte)0xCA,(byte)0x13,(byte)0xB8,(byte)0x11,(byte)0x7D,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x2F, 
            (byte)0x5A,(byte)0xA5,(byte)0x47,(byte)0x45,(byte)0xD5,(byte)0x14,(byte)0x5A,(byte)0x11,(byte)0xB6,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x47, 
            (byte)0x5A,(byte)0xA5,(byte)0x48,(byte)0x45,(byte)0xE0,(byte)0x14,(byte)0xB4,(byte)0x11,(byte)0xD6,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC6, 
//            (byte)0x5A,(byte)0xA5,(byte)0x49,(byte)0x45,(byte)0xEB,(byte)0x15,(byte)0x4,(byte)0x11,(byte)0xF2,(byte)0x0,(byte)0x25,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x43, 
            (byte)0x5A,(byte)0xA5,(byte)0x4A,(byte)0x45,(byte)0xF6,(byte)0x15,(byte)0x7D,(byte)0x12,(byte)0x1B,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA1, 
            (byte)0x5A,(byte)0xA5,(byte)0x4B,(byte)0x46,(byte)0x1,(byte)0x15,(byte)0xDB,(byte)0x12,(byte)0x3A,(byte)0x0,(byte)0x26,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9, 
            (byte)0x5A,(byte)0xA5,(byte)0x4C,(byte)0x46,(byte)0xC,(byte)0x16,(byte)0x9C,(byte)0x12,(byte)0x7A,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1, 
            (byte)0x5A,(byte)0xA5,(byte)0x4D,(byte)0x46,(byte)0x17,(byte)0x17,(byte)0x2C,(byte)0x12,(byte)0xA7,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3D, 
            (byte)0x5A,(byte)0xA5,(byte)0x4E,(byte)0x46,(byte)0x22,(byte)0x17,(byte)0xA6,(byte)0x12,(byte)0xCD,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8F, 
            (byte)0x5A,(byte)0xA5,(byte)0x4F,(byte)0x46,(byte)0x2D,(byte)0x18,(byte)0x13,(byte)0x12,(byte)0xEF,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xEF, 
            (byte)0x5A,(byte)0xA5,(byte)0x50,(byte)0x46,(byte)0x38,(byte)0x18,(byte)0x33,(byte)0x12,(byte)0xF9,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB9, 
            (byte)0x5A,(byte)0xA5,(byte)0x51,(byte)0x46,(byte)0x43,(byte)0x18,(byte)0x33,(byte)0x12,(byte)0xF9,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB0, 
            (byte)0x5A,(byte)0xA5,(byte)0x52,(byte)0x46,(byte)0x4E,(byte)0x18,(byte)0x26,(byte)0x12,(byte)0xF5,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB7, 
            (byte)0x5A,(byte)0xA5,(byte)0x53,(byte)0x46,(byte)0x59,(byte)0x18,(byte)0x16,(byte)0x12,(byte)0xEF,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBE, 
            (byte)0x5A,(byte)0xA5,(byte)0x54,(byte)0x46,(byte)0x64,(byte)0x18,(byte)0xC,(byte)0x12,(byte)0xED,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBE, 
            (byte)0x5A,(byte)0xA5,(byte)0x55,(byte)0x46,(byte)0x6F,(byte)0x17,(byte)0xD9,(byte)0x12,(byte)0xDD,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF7, 
            (byte)0x5A,(byte)0xA5,(byte)0x56,(byte)0x46,(byte)0x7A,(byte)0x17,(byte)0x99,(byte)0x12,(byte)0xC9,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x42, 
            (byte)0x5A,(byte)0xA5,(byte)0x57,(byte)0x46,(byte)0x85,(byte)0x17,(byte)0x55,(byte)0x12,(byte)0xB4,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x89, 
            (byte)0x5A,(byte)0xA5,(byte)0x58,(byte)0x46,(byte)0x90,(byte)0x17,(byte)0x4C,(byte)0x12,(byte)0xB1,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x89, 
            (byte)0x5A,(byte)0xA5,(byte)0x59,(byte)0x46,(byte)0x9B,(byte)0x17,(byte)0x8,(byte)0x12,(byte)0x9C,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD7, 
            (byte)0x5A,(byte)0xA5,(byte)0x5A,(byte)0x46,(byte)0xA6,(byte)0x16,(byte)0xEC,(byte)0x12,(byte)0x93,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF6, 
            (byte)0x5A,(byte)0xA5,(byte)0x5B,(byte)0x46,(byte)0xB1,(byte)0x16,(byte)0xB2,(byte)0x12,(byte)0x81,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x2E, 
            (byte)0x5A,(byte)0xA5,(byte)0x5C,(byte)0x46,(byte)0xBC,(byte)0x16,(byte)0xB2,(byte)0x12,(byte)0x81,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x28, 
            (byte)0x5A,(byte)0xA5,(byte)0x5D,(byte)0x46,(byte)0xC7,(byte)0x16,(byte)0xF5,(byte)0x12,(byte)0x96,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC0, 
            (byte)0x5A,(byte)0xA5,(byte)0x5E,(byte)0x46,(byte)0xD2,(byte)0x17,(byte)0x1C,(byte)0x12,(byte)0xA2,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x83, 
            (byte)0x5A,(byte)0xA5,(byte)0x5F,(byte)0x46,(byte)0xDD,(byte)0x17,(byte)0x18,(byte)0x12,(byte)0xA1,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x7E, 
            (byte)0x5A,(byte)0xA5,(byte)0x60,(byte)0x46,(byte)0xE8,(byte)0x16,(byte)0xDF,(byte)0x12,(byte)0x8F,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBF, 
            (byte)0x5A,(byte)0xA5,(byte)0x61,(byte)0x46,(byte)0xF3,(byte)0x16,(byte)0xC2,(byte)0x12,(byte)0x86,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD3, 
            (byte)0x5A,(byte)0xA5,(byte)0x62,(byte)0x46,(byte)0xFE,(byte)0x17,(byte)0x1C,(byte)0x12,(byte)0xA2,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x50, 
            (byte)0x5A,(byte)0xA5,(byte)0x63,(byte)0x47,(byte)0x9,(byte)0x17,(byte)0x7C,(byte)0x12,(byte)0xC0,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC2, 
            (byte)0x5A,(byte)0xA5,(byte)0x64,(byte)0x47,(byte)0x14,(byte)0x17,(byte)0x62,(byte)0x12,(byte)0xB8,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xDB, 
            (byte)0x5A,(byte)0xA5,(byte)0x65,(byte)0x47,(byte)0x1F,(byte)0x16,(byte)0xC5,(byte)0x12,(byte)0x87,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9D, 
            (byte)0x5A,(byte)0xA5,(byte)0x66,(byte)0x47,(byte)0x2A,(byte)0x15,(byte)0xCF,(byte)0x12,(byte)0x36,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xDC, 
            (byte)0x5A,(byte)0xA5,(byte)0x67,(byte)0x47,(byte)0x35,(byte)0x14,(byte)0xD9,(byte)0x11,(byte)0xE3,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x17, 
            (byte)0x5A,(byte)0xA5,(byte)0x68,(byte)0x47,(byte)0x40,(byte)0x14,(byte)0x2C,(byte)0x11,(byte)0xA6,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFD, 
            (byte)0x5A,(byte)0xA5,(byte)0x69,(byte)0x47,(byte)0x4B,(byte)0x13,(byte)0x88,(byte)0x11,(byte)0x6B,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCF, 
            (byte)0x5A,(byte)0xA5,(byte)0x6A,(byte)0x47,(byte)0x56,(byte)0x13,(byte)0x2F,(byte)0x11,(byte)0x4A,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3C, 
            (byte)0x5A,(byte)0xA5,(byte)0x6B,(byte)0x47,(byte)0x61,(byte)0x12,(byte)0xAD,(byte)0x11,(byte)0x1A,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xDF, 
            (byte)0x5A,(byte)0xA5,(byte)0x6C,(byte)0x47,(byte)0x6C,(byte)0x12,(byte)0x48,(byte)0x10,(byte)0xF3,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x62, 
            (byte)0x5A,(byte)0xA5,(byte)0x6D,(byte)0x47,(byte)0x77,(byte)0x11,(byte)0xB2,(byte)0x10,(byte)0xAE,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x38, 
            (byte)0x5A,(byte)0xA5,(byte)0x6E,(byte)0x47,(byte)0x82,(byte)0x11,(byte)0x31,(byte)0x10,(byte)0x71,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xEA, 
            (byte)0x5A,(byte)0xA5,(byte)0x6F,(byte)0x47,(byte)0x8D,(byte)0x10,(byte)0x7C,(byte)0x10,(byte)0xF,(byte)0x0,(byte)0x14,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFB, 
            (byte)0x5A,(byte)0xA5,(byte)0x70,(byte)0x47,(byte)0x98,(byte)0xF,(byte)0xC5,(byte)0xF,(byte)0xA1,(byte)0x0,(byte)0x15,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x15, 
            (byte)0x5A,(byte)0xA5,(byte)0x71,(byte)0x47,(byte)0xA3,(byte)0xF,(byte)0x88,(byte)0xF,(byte)0x7B,(byte)0x0,(byte)0x13,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0x72,(byte)0x47,(byte)0xAE,(byte)0xF,(byte)0x75,(byte)0xF,(byte)0x6B,(byte)0x0,(byte)0x13,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x85, 
            (byte)0x5A,(byte)0xA5,(byte)0x73,(byte)0x47,(byte)0xB9,(byte)0xF,(byte)0x77,(byte)0xF,(byte)0x6D,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x72, 
            (byte)0x5A,(byte)0xA5,(byte)0x74,(byte)0x47,(byte)0xC4,(byte)0xF,(byte)0x8C,(byte)0xF,(byte)0x7E,(byte)0x0,(byte)0x10,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x46, 
            (byte)0x5A,(byte)0xA5,(byte)0x75,(byte)0x47,(byte)0xCF,(byte)0xF,(byte)0x8C,(byte)0xF,(byte)0x7E,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x34, 
            (byte)0x5A,(byte)0xA5,(byte)0x76,(byte)0x47,(byte)0xDA,(byte)0xF,(byte)0x93,(byte)0xF,(byte)0x83,(byte)0x0,(byte)0xF,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x23, 
            (byte)0x5A,(byte)0xA5,(byte)0x77,(byte)0x47,(byte)0xE5,(byte)0xF,(byte)0x97,(byte)0xF,(byte)0x85,(byte)0x0,(byte)0x16,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA, 
            (byte)0x5A,(byte)0xA5,(byte)0x78,(byte)0x47,(byte)0xF0,(byte)0x10,(byte)0x3,(byte)0xF,(byte)0xC7,(byte)0x0,(byte)0x13,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x52, 
            (byte)0x5A,(byte)0xA5,(byte)0x79,(byte)0x47,(byte)0xFB,(byte)0x10,(byte)0x17,(byte)0xF,(byte)0xD3,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1E, 
            (byte)0x5A,(byte)0xA5,(byte)0x7A,(byte)0x48,(byte)0x6,(byte)0x10,(byte)0x64,(byte)0xF,(byte)0xF9,(byte)0x0,(byte)0x10,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA9, 
            (byte)0x5A,(byte)0xA5,(byte)0x7B,(byte)0x48,(byte)0x11,(byte)0x10,(byte)0xA8,(byte)0x10,(byte)0x27,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1E, 
            (byte)0x5A,(byte)0xA5,(byte)0x7C,(byte)0x48,(byte)0x1C,(byte)0x12,(byte)0xE6,(byte)0x11,(byte)0x2F,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC7, 
            (byte)0x5A,(byte)0xA5,(byte)0x7D,(byte)0x48,(byte)0x27,(byte)0x14,(byte)0x62,(byte)0x11,(byte)0xB9,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB1, 
            (byte)0x5A,(byte)0xA5,(byte)0x7E,(byte)0x48,(byte)0x32,(byte)0x15,(byte)0x62,(byte)0x12,(byte)0x12,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4B, 
            (byte)0x5A,(byte)0xA5,(byte)0x7F,(byte)0x48,(byte)0x3D,(byte)0x16,(byte)0x6C,(byte)0x12,(byte)0x6A,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE0, 
            (byte)0x5A,(byte)0xA5,(byte)0x80,(byte)0x48,(byte)0x48,(byte)0x16,(byte)0xA2,(byte)0x12,(byte)0x7C,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x88, 
            (byte)0x5A,(byte)0xA5,(byte)0x81,(byte)0x48,(byte)0x53,(byte)0x15,(byte)0xCF,(byte)0x12,(byte)0x36,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x99, 
            (byte)0x5A,(byte)0xA5,(byte)0x82,(byte)0x48,(byte)0x5E,(byte)0x15,(byte)0xC,(byte)0x11,(byte)0xF5,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x92, 
            (byte)0x5A,(byte)0xA5,(byte)0x83,(byte)0x48,(byte)0x69,(byte)0x14,(byte)0x8D,(byte)0x11,(byte)0xC8,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x37, 
            (byte)0x5A,(byte)0xA5,(byte)0x84,(byte)0x48,(byte)0x74,(byte)0x14,(byte)0x70,(byte)0x11,(byte)0xBE,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4E, 
            (byte)0x5A,(byte)0xA5,(byte)0x85,(byte)0x48,(byte)0x7F,(byte)0x13,(byte)0xB0,(byte)0x11,(byte)0x75,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x50, 
            (byte)0x5A,(byte)0xA5,(byte)0x86,(byte)0x48,(byte)0x8A,(byte)0x12,(byte)0x48,(byte)0x10,(byte)0xF2,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x29, 
            (byte)0x5A,(byte)0xA5,(byte)0x87,(byte)0x48,(byte)0x95,(byte)0x12,(byte)0x29,(byte)0x10,(byte)0xE4,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4D, 
            (byte)0x5A,(byte)0xA5,(byte)0x88,(byte)0x48,(byte)0xA0,(byte)0x13,(byte)0x4A,(byte)0x11,(byte)0x54,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xAF, 
            (byte)0x5A,(byte)0xA5,(byte)0x89,(byte)0x48,(byte)0xAB,(byte)0x13,(byte)0x75,(byte)0x11,(byte)0x64,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x62, 
            (byte)0x5A,(byte)0xA5,(byte)0x8A,(byte)0x48,(byte)0xB6,(byte)0x13,(byte)0x34,(byte)0x11,(byte)0x4C,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB3, 
            (byte)0x5A,(byte)0xA5,(byte)0x8B,(byte)0x48,(byte)0xC1,(byte)0x13,(byte)0x4F,(byte)0x11,(byte)0x56,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x7F, 
            (byte)0x5A,(byte)0xA5,(byte)0x8C,(byte)0x48,(byte)0xCC,(byte)0x14,(byte)0x81,(byte)0x11,(byte)0xC4,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD5, 
            (byte)0x5A,(byte)0xA5,(byte)0x8D,(byte)0x48,(byte)0xD7,(byte)0x16,(byte)0x3C,(byte)0x12,(byte)0x5A,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x73, 
            (byte)0x5A,(byte)0xA5,(byte)0x8E,(byte)0x48,(byte)0xE2,(byte)0x18,(byte)0x6E,(byte)0x13,(byte)0xB,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x81, 
            (byte)0x5A,(byte)0xA5,(byte)0x8F,(byte)0x48,(byte)0xED,(byte)0x1B,(byte)0x92,(byte)0x13,(byte)0xE7,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x74, 
            (byte)0x5A,(byte)0xA5,(byte)0x90,(byte)0x48,(byte)0xF8,(byte)0x1E,(byte)0x8E,(byte)0x14,(byte)0xA3,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xAF, 
            (byte)0x5A,(byte)0xA5,(byte)0x91,(byte)0x49,(byte)0x3,(byte)0x21,(byte)0x8E,(byte)0x15,(byte)0x45,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFC, 
            (byte)0x5A,(byte)0xA5,(byte)0x92,(byte)0x49,(byte)0xE,(byte)0x24,(byte)0xDB,(byte)0x15,(byte)0xEA,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF4, 
            (byte)0x5A,(byte)0xA5,(byte)0x93,(byte)0x49,(byte)0x19,(byte)0x27,(byte)0x7C,(byte)0x16,(byte)0x63,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCA, 
            (byte)0x5A,(byte)0xA5,(byte)0x94,(byte)0x49,(byte)0x24,(byte)0x29,(byte)0x9A,(byte)0x16,(byte)0xB6,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4E, 
            (byte)0x5A,(byte)0xA5,(byte)0x95,(byte)0x49,(byte)0x2F,(byte)0x2B,(byte)0x50,(byte)0x16,(byte)0xF7,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4A, 
            (byte)0x5A,(byte)0xA5,(byte)0x96,(byte)0x49,(byte)0x3A,(byte)0x2C,(byte)0x70,(byte)0x17,(byte)0x21,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF0, 
            (byte)0x5A,(byte)0xA5,(byte)0x97,(byte)0x49,(byte)0x45,(byte)0x2D,(byte)0x24,(byte)0x17,(byte)0x3B,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x14, 
            (byte)0x5A,(byte)0xA5,(byte)0x98,(byte)0x49,(byte)0x50,(byte)0x2D,(byte)0x54,(byte)0x17,(byte)0x42,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCF, 
            (byte)0x5A,(byte)0xA5,(byte)0x99,(byte)0x49,(byte)0x5B,(byte)0x2C,(byte)0xE6,(byte)0x17,(byte)0x32,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x46, 
            (byte)0x5A,(byte)0xA5,(byte)0x9A,(byte)0x49,(byte)0x66,(byte)0x2C,(byte)0x17,(byte)0x17,(byte)0x14,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x27, 
            (byte)0x5A,(byte)0xA5,(byte)0x9B,(byte)0x49,(byte)0x71,(byte)0x2A,(byte)0xF2,(byte)0x16,(byte)0xE9,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0x9C,(byte)0x49,(byte)0x7C,(byte)0x29,(byte)0x49,(byte)0x16,(byte)0xAA,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4C, 
            (byte)0x5A,(byte)0xA5,(byte)0x9D,(byte)0x49,(byte)0x87,(byte)0x27,(byte)0x82,(byte)0x16,(byte)0x62,(byte)0x0,(byte)0x21,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4E, 
            (byte)0x5A,(byte)0xA5,(byte)0x9E,(byte)0x49,(byte)0x92,(byte)0x26,(byte)0x6D,(byte)0x16,(byte)0x32,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x89, 
            (byte)0x5A,(byte)0xA5,(byte)0x9F,(byte)0x49,(byte)0x9D,(byte)0x24,(byte)0xD6,(byte)0x15,(byte)0xE9,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5D, 
            (byte)0x5A,(byte)0xA5,(byte)0xA0,(byte)0x49,(byte)0xA8,(byte)0x23,(byte)0xAF,(byte)0x15,(byte)0xB0,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB8, 
            (byte)0x5A,(byte)0xA5,(byte)0xA1,(byte)0x49,(byte)0xB3,(byte)0x22,(byte)0x47,(byte)0x15,(byte)0x6A,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x55, 
            (byte)0x5A,(byte)0xA5,(byte)0xA2,(byte)0x49,(byte)0xBE,(byte)0x20,(byte)0xCA,(byte)0x15,(byte)0x1E,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x17, 
            (byte)0x5A,(byte)0xA5,(byte)0xA3,(byte)0x49,(byte)0xC9,(byte)0x1F,(byte)0x55,(byte)0x14,(byte)0xCF,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCE, 
            (byte)0x5A,(byte)0xA5,(byte)0xA4,(byte)0x49,(byte)0xD4,(byte)0x1D,(byte)0xFD,(byte)0x14,(byte)0x83,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0xA5,(byte)0x49,(byte)0xDF,(byte)0x1C,(byte)0xFB,(byte)0x14,(byte)0x42,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA5, 
            (byte)0x5A,(byte)0xA5,(byte)0xA6,(byte)0x49,(byte)0xEA,(byte)0x1B,(byte)0xDA,(byte)0x13,(byte)0xF9,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5, 
            (byte)0x5A,(byte)0xA5,(byte)0xA7,(byte)0x49,(byte)0xF5,(byte)0x1B,(byte)0x1,(byte)0x13,(byte)0xC3,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6, 
            (byte)0x5A,(byte)0xA5,(byte)0xA8,(byte)0x4A,(byte)0x0,(byte)0x1A,(byte)0x37,(byte)0x13,(byte)0x91,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFA, 
            (byte)0x5A,(byte)0xA5,(byte)0xA9,(byte)0x4A,(byte)0xB,(byte)0x19,(byte)0x92,(byte)0x13,(byte)0x63,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC0, 
            (byte)0x5A,(byte)0xA5,(byte)0xAA,(byte)0x4A,(byte)0x16,(byte)0x19,(byte)0x17,(byte)0x13,(byte)0x3E,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x50, 
            (byte)0x5A,(byte)0xA5,(byte)0xAB,(byte)0x4A,(byte)0x21,(byte)0x18,(byte)0xB0,(byte)0x13,(byte)0x1F,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCD, 
            (byte)0x5A,(byte)0xA5,(byte)0xAC,(byte)0x4A,(byte)0x2C,(byte)0x18,(byte)0x30,(byte)0x12,(byte)0xFD,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x64, 
            (byte)0x5A,(byte)0xA5,(byte)0xAD,(byte)0x4A,(byte)0x37,(byte)0x17,(byte)0xEC,(byte)0x12,(byte)0xE3,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB8, 
            (byte)0x5A,(byte)0xA5,(byte)0xAE,(byte)0x4A,(byte)0x42,(byte)0x17,(byte)0xA9,(byte)0x12,(byte)0xCE,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA, 
            (byte)0x5A,(byte)0xA5,(byte)0xAF,(byte)0x4A,(byte)0x4D,(byte)0x17,(byte)0x6F,(byte)0x12,(byte)0xBC,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x48, 
            (byte)0x5A,(byte)0xA5,(byte)0xB0,(byte)0x4A,(byte)0x58,(byte)0x17,(byte)0x35,(byte)0x12,(byte)0xAA,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x87, 
            (byte)0x5A,(byte)0xA5,(byte)0xB1,(byte)0x4A,(byte)0x63,(byte)0x16,(byte)0xDF,(byte)0x12,(byte)0x8F,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xED, 
            (byte)0x5A,(byte)0xA5,(byte)0xB2,(byte)0x4A,(byte)0x6E,(byte)0x16,(byte)0xB8,(byte)0x12,(byte)0x83,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x15, 
            (byte)0x5A,(byte)0xA5,(byte)0xB3,(byte)0x4A,(byte)0x79,(byte)0x16,(byte)0x78,(byte)0x12,(byte)0x6E,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x59, 
            (byte)0x5A,(byte)0xA5,(byte)0xB4,(byte)0x4A,(byte)0x84,(byte)0x16,(byte)0x60,(byte)0x12,(byte)0x66,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0xB5,(byte)0x4A,(byte)0x8F,(byte)0x16,(byte)0x4E,(byte)0x12,(byte)0x60,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x7C, 
            (byte)0x5A,(byte)0xA5,(byte)0xB6,(byte)0x4A,(byte)0x9A,(byte)0x16,(byte)0x51,(byte)0x12,(byte)0x61,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0xB7,(byte)0x4A,(byte)0xA5,(byte)0x16,(byte)0x54,(byte)0x12,(byte)0x62,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5A, 
            (byte)0x5A,(byte)0xA5,(byte)0xB8,(byte)0x4A,(byte)0xB0,(byte)0x16,(byte)0x29,(byte)0x12,(byte)0x54,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8C, 
            (byte)0x5A,(byte)0xA5,(byte)0xB9,(byte)0x4A,(byte)0xBB,(byte)0x16,(byte)0x17,(byte)0x12,(byte)0x4E,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x95, 
            (byte)0x5A,(byte)0xA5,(byte)0xBA,(byte)0x4A,(byte)0xC6,(byte)0x16,(byte)0x11,(byte)0x12,(byte)0x4B,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x93, 
            (byte)0x5A,(byte)0xA5,(byte)0xBB,(byte)0x4A,(byte)0xD1,(byte)0x16,(byte)0x8,(byte)0x12,(byte)0x49,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8F, 
            (byte)0x5A,(byte)0xA5,(byte)0xBC,(byte)0x4A,(byte)0xDC,(byte)0x16,(byte)0x29,(byte)0x12,(byte)0x54,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5A, 
            (byte)0x5A,(byte)0xA5,(byte)0xBD,(byte)0x4A,(byte)0xE7,(byte)0x16,(byte)0x33,(byte)0x12,(byte)0x57,(byte)0x0,(byte)0x23,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3A, 
            (byte)0x5A,(byte)0xA5,(byte)0xBE,(byte)0x4A,(byte)0xF2,(byte)0x16,(byte)0x54,(byte)0x12,(byte)0x62,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8, 
            (byte)0x5A,(byte)0xA5,(byte)0xBF,(byte)0x4A,(byte)0xFD,(byte)0x16,(byte)0x5D,(byte)0x12,(byte)0x65,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xEE, 
            (byte)0x5A,(byte)0xA5,(byte)0xC0,(byte)0x4B,(byte)0x8,(byte)0x16,(byte)0x57,(byte)0x12,(byte)0x63,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE8, 
            (byte)0x5A,(byte)0xA5,(byte)0xC1,(byte)0x4B,(byte)0x13,(byte)0x16,(byte)0x4B,(byte)0x12,(byte)0x5F,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF1, 
            (byte)0x5A,(byte)0xA5,(byte)0xC2,(byte)0x4B,(byte)0x1E,(byte)0x16,(byte)0x54,(byte)0x12,(byte)0x62,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD6, 
            (byte)0x5A,(byte)0xA5,(byte)0xC3,(byte)0x4B,(byte)0x29,(byte)0x16,(byte)0x57,(byte)0x12,(byte)0x63,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCC, 
            (byte)0x5A,(byte)0xA5,(byte)0xC4,(byte)0x4B,(byte)0x34,(byte)0x16,(byte)0x51,(byte)0x12,(byte)0x61,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC0, 
            (byte)0x5A,(byte)0xA5,(byte)0xC5,(byte)0x4B,(byte)0x3F,(byte)0x16,(byte)0x54,(byte)0x12,(byte)0x67,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xAD, 
            (byte)0x5A,(byte)0xA5,(byte)0xC6,(byte)0x4B,(byte)0x4A,(byte)0x16,(byte)0x63,(byte)0x12,(byte)0x67,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x93, 
            (byte)0x5A,(byte)0xA5,(byte)0xC7,(byte)0x4B,(byte)0x55,(byte)0x16,(byte)0x4B,(byte)0x12,(byte)0x5F,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA6, 
            (byte)0x5A,(byte)0xA5,(byte)0xC8,(byte)0x4B,(byte)0x60,(byte)0x16,(byte)0x57,(byte)0x12,(byte)0x63,(byte)0x0,(byte)0x22,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x86, 
            (byte)0x5A,(byte)0xA5,(byte)0xC9,(byte)0x4B,(byte)0x6B,(byte)0x16,(byte)0x48,(byte)0x12,(byte)0x5E,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x90, 
            (byte)0x5A,(byte)0xA5,(byte)0xCA,(byte)0x4B,(byte)0x76,(byte)0x16,(byte)0x29,(byte)0x12,(byte)0x54,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB1, 
            (byte)0x5A,(byte)0xA5,(byte)0xCB,(byte)0x4B,(byte)0x81,(byte)0x16,(byte)0xE,(byte)0x12,(byte)0x4B,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC9, 
            (byte)0x5A,(byte)0xA5,(byte)0xCC,(byte)0x4B,(byte)0x8C,(byte)0x15,(byte)0xF0,(byte)0x12,(byte)0x41,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE5, 
            (byte)0x5A,(byte)0xA5,(byte)0xCD,(byte)0x4B,(byte)0x97,(byte)0x15,(byte)0xB1,(byte)0x12,(byte)0x2C,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x30, 
            (byte)0x5A,(byte)0xA5,(byte)0xCE,(byte)0x4B,(byte)0xA2,(byte)0x15,(byte)0x83,(byte)0x12,(byte)0x1D,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x60, 
            (byte)0x5A,(byte)0xA5,(byte)0xCF,(byte)0x4B,(byte)0xAD,(byte)0x15,(byte)0x71,(byte)0x12,(byte)0x17,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6C, 
            (byte)0x5A,(byte)0xA5,(byte)0xD0,(byte)0x4B,(byte)0xB8,(byte)0x15,(byte)0x2C,(byte)0x12,(byte)0x0,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xBD, 
            (byte)0x5A,(byte)0xA5,(byte)0xD1,(byte)0x4B,(byte)0xC3,(byte)0x14,(byte)0xF8,(byte)0x11,(byte)0xEE,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF6, 
            (byte)0x5A,(byte)0xA5,(byte)0xD2,(byte)0x4B,(byte)0xCE,(byte)0x14,(byte)0xBA,(byte)0x11,(byte)0xD8,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x3F, 
            (byte)0x5A,(byte)0xA5,(byte)0xD3,(byte)0x4B,(byte)0xD9,(byte)0x14,(byte)0x79,(byte)0x11,(byte)0xC0,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8C, 
            (byte)0x5A,(byte)0xA5,(byte)0xD4,(byte)0x4B,(byte)0xE4,(byte)0x14,(byte)0x38,(byte)0x11,(byte)0xAA,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD9, 
            (byte)0x5A,(byte)0xA5,(byte)0xD5,(byte)0x4B,(byte)0xEF,(byte)0x14,(byte)0x2,(byte)0x11,(byte)0x97,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x14, 
            (byte)0x5A,(byte)0xA5,(byte)0xD6,(byte)0x4B,(byte)0xFA,(byte)0x13,(byte)0xB6,(byte)0x11,(byte)0x7C,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x6E, 
            (byte)0x5A,(byte)0xA5,(byte)0xD7,(byte)0x4C,(byte)0x5,(byte)0x13,(byte)0x8A,(byte)0x11,(byte)0x6C,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA0, 
            (byte)0x5A,(byte)0xA5,(byte)0xD8,(byte)0x4C,(byte)0x10,(byte)0x13,(byte)0x52,(byte)0x11,(byte)0x57,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE0, 
            (byte)0x5A,(byte)0xA5,(byte)0xD9,(byte)0x4C,(byte)0x1B,(byte)0x13,(byte)0x1E,(byte)0x11,(byte)0x44,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x1F, 
            (byte)0x5A,(byte)0xA5,(byte)0xDA,(byte)0x4C,(byte)0x26,(byte)0x12,(byte)0xE6,(byte)0x11,(byte)0x2F,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x5E, 
            (byte)0x5A,(byte)0xA5,(byte)0xDB,(byte)0x4C,(byte)0x31,(byte)0x12,(byte)0xBA,(byte)0x11,(byte)0x1F,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x8C, 
            (byte)0x5A,(byte)0xA5,(byte)0xDC,(byte)0x4C,(byte)0x3C,(byte)0x12,(byte)0xA5,(byte)0x11,(byte)0x17,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9C, 
            (byte)0x5A,(byte)0xA5,(byte)0xDD,(byte)0x4C,(byte)0x47,(byte)0x12,(byte)0x6F,(byte)0x11,(byte)0x3,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD8, 
            (byte)0x5A,(byte)0xA5,(byte)0xDE,(byte)0x4C,(byte)0x52,(byte)0x12,(byte)0x59,(byte)0x10,(byte)0xFA,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xEE, 
            (byte)0x5A,(byte)0xA5,(byte)0xDF,(byte)0x4C,(byte)0x5D,(byte)0x12,(byte)0x48,(byte)0x10,(byte)0xF2,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFB, 
            (byte)0x5A,(byte)0xA5,(byte)0xE0,(byte)0x4C,(byte)0x68,(byte)0x12,(byte)0xA,(byte)0x10,(byte)0xD6,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4B, 
            (byte)0x5A,(byte)0xA5,(byte)0xE1,(byte)0x4C,(byte)0x73,(byte)0x11,(byte)0xF8,(byte)0x10,(byte)0xCE,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x59, 
            (byte)0x5A,(byte)0xA5,(byte)0xE2,(byte)0x4C,(byte)0x7E,(byte)0x11,(byte)0xD3,(byte)0x10,(byte)0xBD,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x84, 
            (byte)0x5A,(byte)0xA5,(byte)0xE3,(byte)0x4C,(byte)0x89,(byte)0x11,(byte)0xB6,(byte)0x10,(byte)0xB0,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA3, 
            (byte)0x5A,(byte)0xA5,(byte)0xE4,(byte)0x4C,(byte)0x94,(byte)0x11,(byte)0xB8,(byte)0x10,(byte)0xB1,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x95, 
            (byte)0x5A,(byte)0xA5,(byte)0xE5,(byte)0x4C,(byte)0x9F,(byte)0x11,(byte)0x9E,(byte)0x10,(byte)0xA5,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xAD, 
            (byte)0x5A,(byte)0xA5,(byte)0xE6,(byte)0x4C,(byte)0xAA,(byte)0x11,(byte)0x91,(byte)0x10,(byte)0x9F,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB4, 
            (byte)0x5A,(byte)0xA5,(byte)0xE7,(byte)0x4C,(byte)0xB5,(byte)0x11,(byte)0x86,(byte)0x10,(byte)0x9A,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB7, 
            (byte)0x5A,(byte)0xA5,(byte)0xE8,(byte)0x4C,(byte)0xC0,(byte)0x11,(byte)0x63,(byte)0x10,(byte)0x8A,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE3, 
            (byte)0x5A,(byte)0xA5,(byte)0xE9,(byte)0x4C,(byte)0xCB,(byte)0x11,(byte)0x6B,(byte)0x10,(byte)0x8E,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC3, 
            (byte)0x5A,(byte)0xA5,(byte)0xEA,(byte)0x4C,(byte)0xD6,(byte)0x11,(byte)0x58,(byte)0x10,(byte)0x85,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD8, 
            (byte)0x5A,(byte)0xA5,(byte)0xEB,(byte)0x4C,(byte)0xE1,(byte)0x11,(byte)0x47,(byte)0x10,(byte)0x7D,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE3, 
            (byte)0x5A,(byte)0xA5,(byte)0xEC,(byte)0x4C,(byte)0xEC,(byte)0x11,(byte)0x28,(byte)0x10,(byte)0x67,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE, 
            (byte)0x5A,(byte)0xA5,(byte)0xED,(byte)0x4C,(byte)0xF7,(byte)0x11,(byte)0x29,(byte)0x10,(byte)0x6D,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xF9, 
            (byte)0x5A,(byte)0xA5,(byte)0xEE,(byte)0x4D,(byte)0x2,(byte)0x11,(byte)0xE,(byte)0x10,(byte)0x5E,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x18, 
            (byte)0x5A,(byte)0xA5,(byte)0xEF,(byte)0x4D,(byte)0xD,(byte)0x11,(byte)0x3,(byte)0x10,(byte)0x58,(byte)0x0,(byte)0x1F,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x19, 
            (byte)0x5A,(byte)0xA5,(byte)0xF0,(byte)0x4D,(byte)0x18,(byte)0x10,(byte)0xFA,(byte)0x10,(byte)0x53,(byte)0x0,(byte)0x18,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x23, 
            (byte)0x5A,(byte)0xA5,(byte)0xF1,(byte)0x4D,(byte)0x23,(byte)0x10,(byte)0xE5,(byte)0x10,(byte)0x48,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x36, 
            (byte)0x5A,(byte)0xA5,(byte)0xF2,(byte)0x4D,(byte)0x2E,(byte)0x10,(byte)0xE5,(byte)0x10,(byte)0x48,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x29, 
            (byte)0x5A,(byte)0xA5,(byte)0xF3,(byte)0x4D,(byte)0x39,(byte)0x10,(byte)0xFA,(byte)0x10,(byte)0x53,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xFA, 
            (byte)0x5A,(byte)0xA5,(byte)0xF4,(byte)0x4D,(byte)0x44,(byte)0x10,(byte)0xFD,(byte)0x10,(byte)0x55,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xE9, 
            (byte)0x5A,(byte)0xA5,(byte)0xF5,(byte)0x4D,(byte)0x4F,(byte)0x11,(byte)0x1,(byte)0x10,(byte)0x57,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xD9, 
            (byte)0x5A,(byte)0xA5,(byte)0xF6,(byte)0x4D,(byte)0x5A,(byte)0x11,(byte)0x1,(byte)0x10,(byte)0x57,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC9, 
            (byte)0x5A,(byte)0xA5,(byte)0xF7,(byte)0x4D,(byte)0x65,(byte)0x10,(byte)0xFF,(byte)0x10,(byte)0x56,(byte)0x0,(byte)0x1C,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xC3, 
            (byte)0x5A,(byte)0xA5,(byte)0xF8,(byte)0x4D,(byte)0x70,(byte)0x10,(byte)0xFF,(byte)0x10,(byte)0x56,(byte)0x0,(byte)0x20,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xB3, 
            (byte)0x5A,(byte)0xA5,(byte)0xF9,(byte)0x4D,(byte)0x7B,(byte)0x11,(byte)0x5,(byte)0x10,(byte)0x59,(byte)0x0,(byte)0x1B,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xA2, 
            (byte)0x5A,(byte)0xA5,(byte)0xFA,(byte)0x4D,(byte)0x86,(byte)0x10,(byte)0xFF,(byte)0x10,(byte)0x5A,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x9A, 
            (byte)0x5A,(byte)0xA5,(byte)0xFB,(byte)0x4D,(byte)0x91,(byte)0x11,(byte)0x12,(byte)0x10,(byte)0x60,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x74, 
            (byte)0x5A,(byte)0xA5,(byte)0xFC,(byte)0x4D,(byte)0x9C,(byte)0x11,(byte)0x3C,(byte)0x10,(byte)0x77,(byte)0x0,(byte)0x17,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x2D, 
            (byte)0x5A,(byte)0xA5,(byte)0xFD,(byte)0x4D,(byte)0xA7,(byte)0x11,(byte)0x33,(byte)0x10,(byte)0x72,(byte)0x0,(byte)0x1A,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x2C, 
            (byte)0x5A,(byte)0xA5,(byte)0xFE,(byte)0x4D,(byte)0xB2,(byte)0x11,(byte)0x69,(byte)0x10,(byte)0x8D,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0xCB, 
            (byte)0x5A,(byte)0xA5,(byte)0xFF,(byte)0x4D,(byte)0xBD,(byte)0x11,(byte)0x88,(byte)0x10,(byte)0x9B,(byte)0x0,(byte)0x19,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x97, 
            (byte)0x5A,(byte)0xA5,(byte)0x0,(byte)0x4D,(byte)0xC8,(byte)0x11,(byte)0x93,(byte)0x10,(byte)0xA0,(byte)0x0,(byte)0x1E,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x76, 
            (byte)0x5A,(byte)0xA5,(byte)0x1,(byte)0x4D,(byte)0xD3,(byte)0x11,(byte)0xA7,(byte)0x10,(byte)0xA9,(byte)0x0,(byte)0x1D,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x0,(byte)0x3,(byte)0x0,(byte)0x4E, 
    };
    private int index;
    private byte[] result = new byte[1];

    public void write(byte[] bytes) {
        throw new UnsupportedOperationException();
    }

    public int available() {
        return 1;
    }

    public void read(byte[] bytes) {
        if (bytes.length != 1) throw new IllegalArgumentException();
        if (index >= data.length) index = 0;
        bytes[0] = data[index++];
        sleep(1);
    }

    public byte[] readAvailable() {
        throw new UnsupportedOperationException();
    }

    public void readStaleData() {
        throw new UnsupportedOperationException();
    }

    public String readLine() {
        throw new UnsupportedOperationException();
    }

    public int read() {
        read(result);
        return result[0];
    }

    public void close() {
        index = 0;
    }

    public void sendBreak(int duration) {
    }
}
